@@ -168,7 +168,7 @@ class CGDB:
             else:
                 self.create_element_context(self.element(element_code), aggregation_code,
                                             self.time_step(time_step_code))
-        self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, data_set_type, elementMarkOverride,)
+        self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, level_code, data_set_type, elementMarkOverride,)
 
     def create_station(self, name: str, code: str, gpsLatitude: float, gpsLongitude: float, altitude: int, stationNetworkCode, remark=""):
         """Create station
