@@ -85,7 +85,7 @@ class DataSetsManager(ManagerMix):
 
             data_page = pd.DataFrame(records)
             data_page["timestamp"] = pd.to_datetime(data_page['timestamp'], unit="s")
-            data_page.timestamp = data_page.timestamp.dt.tz_localize('UTC').dt.tz_convert('Europe/Brussels')
+            # data_page.timestamp = data_page.timestamp.dt.tz_localize('UTC').dt.tz_convert('Europe/Brussels')
             data_page.rename(columns={"timestamp": "datetime", "value": data_set.code}, inplace=True)
             for parameter in data_set.parameters:
                 if parameter.name in data_page.columns and parameter.type in ["INTEGER", "DOUBLE"]:
